@@ -51,13 +51,13 @@ class LiveClient(WebSocketApp):
         if 'trade' in msg.keys():
             trade = msg['trade']
             self.handle_trade_data(trade)
-        elif 'b' in msg.keys():
+        elif 'bidask' in msg.keys():
             pass
 
     def handle_message_data(self, msg):
-        print(f"This ping contains a message = {msg['message']}")
+        print(f"Truedata has this message for you -> {msg['message']}")
         if msg['message'] == 'TrueData Real Time Data Service':  # Connection success message
-            print(f"You can trade on {msg['segments']}")
+            print(f"You can trade on {msg['segments']}")  # TODO: Format statement better
         if msg['message'] == 'invalid request':
             print('raising request error')
             raise TDInvalidRequestError
@@ -71,12 +71,11 @@ class LiveClient(WebSocketApp):
             contract_details = contract.split(':')
             self.contract_mapping[int(contract_details[1])] = symbol = contract_details[0]
             for ticker_id in self.parent_app.symbol_mkt_id_map[symbol]:
-                self.parent_app.touchline_data[ticker_id] = TouchlineData()
                 self.parent_app.touchline_data[ticker_id].symbol = symbol
                 self.parent_app.touchline_data[ticker_id].truedata_id = int(contract_details[1])
-                self.parent_app.touchline_data[ticker_id].open = float(contract_details[2])
-                self.parent_app.touchline_data[ticker_id].high = float(contract_details[3])
-                self.parent_app.touchline_data[ticker_id].low = float(contract_details[4])
+                self.parent_app.touchline_data[ticker_id].open = self.parent_app.live_data[ticker_id].day_open = float(contract_details[2])
+                self.parent_app.touchline_data[ticker_id].high = self.parent_app.live_data[ticker_id].day_high = float(contract_details[3])
+                self.parent_app.touchline_data[ticker_id].low = self.parent_app.live_data[ticker_id].day_low = float(contract_details[4])
                 self.parent_app.touchline_data[ticker_id].close = float(contract_details[5])
                 self.parent_app.touchline_data[ticker_id].prev_close = float(contract_details[6])
                 self.parent_app.touchline_data[ticker_id].ttq = int(contract_details[7])
@@ -105,11 +104,9 @@ class LiveClient(WebSocketApp):
                     self.parent_app.live_data[ticker_id].special_tag = special_tag = str(trade_tick[11])
                     if self.parent_app.live_data[ticker_id].special_tag != "":
                         if special_tag == 'H':
-                            print(f"{Style.BRIGHT}{Fore.GREEN}NEW DAY'S HIGH for {symbol}...{Style.RESET_ALL}")
-                            self.parent_app.live_data[ticker_id].day_high = ltp
+                            self.parent_app.live_data[ticker_id].day_high = self.parent_app.touchline_data[ticker_id].high = ltp
                         elif special_tag == 'L':
-                            print(f"{Style.BRIGHT}{Fore.RED}NEW DAY'S LOW for {symbol}...{Style.RESET_ALL}")
-                            self.parent_app.live_data[ticker_id].day_low = ltp
+                            self.parent_app.live_data[ticker_id].day_low = self.parent_app.touchline_data[ticker_id].low = ltp
                 except IndexError:
                     # Happens when not subscribed to bid-ask data in streaming data
                     pass
@@ -222,9 +219,29 @@ class TD:
     def get_historic_data(self, contract,
                           ticker_id=DEFAULT_HISTORIC_DATA_ID,
                           query_time=None,
-                          duration="1 D",
+                          duration=None,
+                          start_time=None,
                           bar_size="1 min"):
         global DEFAULT_HISTORIC_DATA_ID
+        if duration is not None:
+            return self.get_historical_data_from_duration(contract=contract,
+                                                          ticker_id=ticker_id,
+                                                          query_time=query_time,
+                                                          duration=duration,
+                                                          bar_size=bar_size)
+        elif start_time is not None:
+            return self.get_historic_data_from_start_time(contract=contract,
+                                                          ticker_id=ticker_id,
+                                                          query_time=query_time,
+                                                          start_time=start_time,
+                                                          bar_size=bar_size)
+
+    def get_historical_data_from_duration(self, contract,
+                                          ticker_id=DEFAULT_HISTORIC_DATA_ID,
+                                          query_time=None,
+                                          duration="1 D",
+                                          bar_size="1 min"):
+        global DEFAULT_HISTORIC_DATA_ID
         if query_time is None:
             query_time = datetime.today()
         start_time = self.truedata_duration_map(duration, query_time)
@@ -242,20 +259,42 @@ class TD:
         self.hist_data[ticker_id] = hist_data
         return hist_data
 
+    def get_historic_data_from_start_time(self, contract,
+                                          ticker_id=DEFAULT_HISTORIC_DATA_ID,
+                                          query_time=None,
+                                          start_time=None,
+                                          bar_size="1 min"):
+        global DEFAULT_HISTORIC_DATA_ID
+        if query_time is None:
+            query_time = datetime.today()
+        if start_time is None:
+            start_time = datetime.today()
+
+        if bar_size == 'tick':
+            hist_data = self.historical_websocket.get_hist_tick_data(contract, )
+        else:
+            bar_size = bar_size.replace(' ', '')
+            if bar_size[-1] == 's':
+                bar_size = bar_size[:-1]
+            query_time = query_time.strftime('%Y-%m-%d') + 'T23:59:59'
+            start_time = start_time.strftime('%Y-%m-%d') + 'T00:00:00'
+            hist_data = self.historical_websocket.get_hist_bar_data(contract, query_time, start_time, bar_size)
+        DEFAULT_HISTORIC_DATA_ID = DEFAULT_HISTORIC_DATA_ID + 1
+        self.hist_data[ticker_id] = hist_data
+        return hist_data
+
     def start_live_data(self, resolved_contract, req_id=None):
         global DEFAULT_MARKET_DATA_ID
         if req_id is None:
             req_id = DEFAULT_MARKET_DATA_ID
         if type(resolved_contract) == str:
             # self.live_data_contracts[req_id] = resolved_contract
+            self.touchline_data[req_id] = TouchlineData()
             self.live_data[req_id] = LiveData(resolved_contract)
             try:
-                print('Adding to existing')
                 self.symbol_mkt_id_map[resolved_contract.upper()].append(req_id)
-                print('Adding to existing... SUCCESS')
             except KeyError:
                 self.symbol_mkt_id_map[resolved_contract.upper()] = [req_id]
-                print('Creating new... SUCCESS')
             self.live_websocket.send(f'{{"method": "addsymbol", "symbols": ["{resolved_contract}"]}}')
             DEFAULT_MARKET_DATA_ID = DEFAULT_MARKET_DATA_ID + 1
             return req_id
@@ -278,14 +317,12 @@ class TD:
                         req_ids.append(curr_req_id + i)
             for j in range(0, len(req_ids)):
                 print(j)
+                self.touchline_data[req_ids[j]] = TouchlineData()
                 self.live_data[req_ids[j]] = LiveData(resolved_contract[j])
                 try:
-                    print('Adding to existing')
                     self.symbol_mkt_id_map[resolved_contract[j].upper()].append(req_ids[j])
-                    print('Adding to existing... SUCCESS')
                 except KeyError:
                     self.symbol_mkt_id_map[resolved_contract[j].upper()] = [req_ids[j]]
-                    print('Creating new... SUCCESS')
                 self.live_websocket.send(f'{{"method": "addsymbol", "symbols": ["{resolved_contract[j]}"]}}')
             return req_ids
 
