@@ -1,4 +1,6 @@
 from colorama import Style, Fore
+from copy import deepcopy
+
 
 class LiveData:
     def __init__(self, symbol):
@@ -53,7 +55,10 @@ class LiveData:
             elif self.special_tag == "":
                 self.starting_formatter = f"{Style.BRIGHT} {Fore.RED}"
             self.ending_formatter = f"{Style.RESET_ALL}"
-        return f"{self.starting_formatter} {str(self.__dict__)} {self.ending_formatter}"
+        op_dict = deepcopy(self.__dict__)
+        del op_dict['starting_formatter']
+        del op_dict['ending_formatter']
+        return f"{self.starting_formatter} {str(op_dict)} {self.ending_formatter}"
 
 
 class TouchlineData:
